@@ -1,6 +1,7 @@
 from .darkknight import DarkKnight
 from .ftp import Ftp
 from .ftps import Ftps
+from .ftps_toucan import Ftps_toucan
 from .geolocator import GeoLocator
 from .git import Git
 from .google_spreadsheet import GoogleSpreadsheet
@@ -15,12 +16,13 @@ from .prediction import Prediction
 from .sentiment_analysis import SentimentAnalysis
 from .toucan import Toucan
 
-__version__ = "0.8.3"
+__version__ = "0.9.2"
 
 darkknight = DarkKnight
 ftp = Ftp
-git = Git
 ftps = Ftps
+ftps_toucan = Ftps_toucan
+git = Git
 geoLocator = GeoLocator
 google_spreadsheet = GoogleSpreadsheet
 healthCheck = HealthCheck
